package com.example.what_the_fantasy.data.retrofit

import com.example.what_the_fantasy.data.model.SrcLanguage
import com.example.what_the_fantasy.data.model.User
import retrofit2.Response
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import retrofit2.http.Body
import retrofit2.http.GET
import retrofit2.http.POST
import retrofit2.http.Path
import retrofit2.http.Query

data class UserUpdateRequest(
    val username: String,
    val email: String,
    val passwd: String,
    val langage: SrcLanguage,
    val imgUrl: String
)

interface UserApiService {

    @GET("users/username")
    suspend fun getUserByUsername(
        @Query("username") username: String
    ): User

    @GET("users/{id}")
    suspend fun getUserById(
        @Path("id") id: Int
    ): User


    @POST("users")
    suspend fun updateUser(
        @Query("id") id: Int,
        @Body userUpdate: UserUpdateRequest
    ): Response<User>
}


object RetrofitInstance {
    private const val BASE_URL = "https://codefirst.iut.uca.fr/containers/WhatTheFantasy-web-services/api/v1/"

    val api: UserApiService by lazy {
        Retrofit.Builder()
            .baseUrl(BASE_URL)
            .addConverterFactory(GsonConverterFactory.create())
            .build()
            .create(UserApiService::class.java)
    }
}